==> kubernetes-model-1.0.45-sources.jar: io/fabric8/kubernetes/api/model/extensions/ReplicaSetSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;

public class ReplicaSetSpecFluentImpl<T extends ReplicaSetSpecFluent<T>> extends BaseFluent<T> implements ReplicaSetSpecFluent<T>{

     Integer replicas;     VisitableBuilder<LabelSelector, ?> selector;     VisitableBuilder<PodTemplateSpec, ?> template;     Map<String, Object> additionalProperties = new HashMap();
public ReplicaSetSpecFluentImpl(){
    
}
public ReplicaSetSpecFluentImpl( ReplicaSetSpec instance ){
    this.withReplicas(instance.getReplicas()); this.withSelector(instance.getSelector()); this.withTemplate(instance.getTemplate()); 
}

    public Integer getReplicas(){
    return this.replicas;
    }
    public T withReplicas( Integer replicas){
    this.replicas=replicas; return (T) this;
    }
    public LabelSelector getSelector(){
    return this.selector!=null?this.selector.build():null;
    }
    public T withSelector( LabelSelector selector){
    if (selector!=null){ this.selector= new LabelSelectorBuilder(selector); _visitables.add(this.selector);} return (T) this;
    }
    public SelectorNested<T> withNewSelector(){
    return new SelectorNestedImpl<T>();
    }
    public SelectorNested<T> withNewSelectorLike( LabelSelector item){
    return new SelectorNestedImpl<T>(item);
    }
    public SelectorNested<T> editSelector(){
    return withNewSelectorLike(getSelector());
    }
    public PodTemplateSpec getTemplate(){
    return this.template!=null?this.template.build():null;
    }
    public T withTemplate( PodTemplateSpec template){
    if (template!=null){ this.template= new PodTemplateSpecBuilder(template); _visitables.add(this.template);} return (T) this;
    }
    public TemplateNested<T> withNewTemplate(){
    return new TemplateNestedImpl<T>();
    }
    public TemplateNested<T> withNewTemplateLike( PodTemplateSpec item){
    return new TemplateNestedImpl<T>(item);
    }
    public TemplateNested<T> editTemplate(){
    return withNewTemplateLike(getTemplate());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ReplicaSetSpecFluentImpl that = (ReplicaSetSpecFluentImpl) o;
if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
if (template != null ? !template.equals(that.template) :that.template != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class SelectorNestedImpl<N> extends LabelSelectorFluentImpl<SelectorNested<N>> implements SelectorNested<N>{

        private final LabelSelectorBuilder builder;
    
             SelectorNestedImpl (){
        this.builder = new LabelSelectorBuilder(this);
        }
             SelectorNestedImpl ( LabelSelector item){
        this.builder = new LabelSelectorBuilder(this, item);
        }
    
            public N endSelector(){
            return and();
        }
            public N and(){
            return (N) ReplicaSetSpecFluentImpl.this.withSelector(builder.build());
        }
    
}
    public class TemplateNestedImpl<N> extends PodTemplateSpecFluentImpl<TemplateNested<N>> implements TemplateNested<N>{

        private final PodTemplateSpecBuilder builder;
    
             TemplateNestedImpl (){
        this.builder = new PodTemplateSpecBuilder(this);
        }
             TemplateNestedImpl ( PodTemplateSpec item){
        this.builder = new PodTemplateSpecBuilder(this, item);
        }
    
            public N endTemplate(){
            return and();
        }
            public N and(){
            return (N) ReplicaSetSpecFluentImpl.this.withTemplate(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/extensions/ReplicaSetSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;

public class ReplicaSetSpecFluentImpl<A extends ReplicaSetSpecFluent<A>> extends BaseFluent<A> implements ReplicaSetSpecFluent<A>{

     Integer replicas;     VisitableBuilder<LabelSelector, ?> selector;     VisitableBuilder<PodTemplateSpec, ?> template;
public ReplicaSetSpecFluentImpl(){
    
}
public ReplicaSetSpecFluentImpl( ReplicaSetSpec instance ){
    this.withReplicas(instance.getReplicas()); this.withSelector(instance.getSelector()); this.withTemplate(instance.getTemplate()); 
}

    public Integer getReplicas(){
    return this.replicas;
    }
    public A withReplicas( Integer replicas){
    this.replicas=replicas; return (A) this;
    }
    public LabelSelector getSelector(){
    return this.selector!=null?this.selector.build():null;
    }
    public A withSelector( LabelSelector selector){
    if (selector!=null){ this.selector= new LabelSelectorBuilder(selector); _visitables.add(this.selector);} return (A) this;
    }
    public SelectorNested<A> withNewSelector(){
    return new SelectorNestedImpl();
    }
    public SelectorNested<A> withNewSelectorLike( LabelSelector item){
    return new SelectorNestedImpl(item);
    }
    public SelectorNested<A> editSelector(){
    return withNewSelectorLike(getSelector());
    }
    public PodTemplateSpec getTemplate(){
    return this.template!=null?this.template.build():null;
    }
    public A withTemplate( PodTemplateSpec template){
    if (template!=null){ this.template= new PodTemplateSpecBuilder(template); _visitables.add(this.template);} return (A) this;
    }
    public TemplateNested<A> withNewTemplate(){
    return new TemplateNestedImpl();
    }
    public TemplateNested<A> withNewTemplateLike( PodTemplateSpec item){
    return new TemplateNestedImpl(item);
    }
    public TemplateNested<A> editTemplate(){
    return withNewTemplateLike(getTemplate());
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ReplicaSetSpecFluentImpl that = (ReplicaSetSpecFluentImpl) o;
if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
if (template != null ? !template.equals(that.template) :that.template != null) return false;
return true;

    }

    public class SelectorNestedImpl<N> extends LabelSelectorFluentImpl<SelectorNested<N>> implements SelectorNested<N>{

        private final LabelSelectorBuilder builder;
    
             SelectorNestedImpl (){
        this.builder = new LabelSelectorBuilder(this);
        }
             SelectorNestedImpl ( LabelSelector item){
        this.builder = new LabelSelectorBuilder(this, item);
        }
    
            public N endSelector(){
            return and();
        }
            public N and(){
            return (N) ReplicaSetSpecFluentImpl.this.withSelector(builder.build());
        }
    
}
    public class TemplateNestedImpl<N> extends PodTemplateSpecFluentImpl<TemplateNested<N>> implements TemplateNested<N>{

        private final PodTemplateSpecBuilder builder;
    
             TemplateNestedImpl (){
        this.builder = new PodTemplateSpecBuilder(this);
        }
             TemplateNestedImpl ( PodTemplateSpec item){
        this.builder = new PodTemplateSpecBuilder(this, item);
        }
    
            public N endTemplate(){
            return and();
        }
            public N and(){
            return (N) ReplicaSetSpecFluentImpl.this.withTemplate(builder.build());
        }
    
}


}
